@@ -4,14 +4,13 @@ import logging as _logging
 
 from . import spells, types
 from ._group import TodoGroup
-from ._magic import MagicTodo, MagicTodoMixin
+from ._magic import MagicTodoMixin
 from ._shared import DEFAULT_PRIORITY
 from ._todo import Todo
 
 
 __all__ = [
     "DEFAULT_PRIORITY",
-    "MagicTodo",
     "MagicTodoMixin",
     "Todo",
     "TodoGroup",
@@ -21,6 +20,6 @@ __all__ = [
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.6.0"
+__version__ = "0.7.1"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
