@@ -4,9 +4,10 @@ from __future__ import annotations
 
 import datetime as dt
 from typing import (
-    TYPE_CHECKING,
+    Any,
     Callable,
     Dict,
+    Generic,
     List,
     Literal,
     Optional,
@@ -19,17 +20,14 @@ from typing import (
 )
 
 from eris import ErisError, Result
-from typist import Comparable, ToDictable
-
-
-if TYPE_CHECKING:
-    from ._todo import Todo  # pragma: no cover
+from typist import Comparable
 
 
 # Type Variables (i.e. `TypeVar`s)
-Todo_T = TypeVar("Todo_T", bound="AbstractTodo")
-MagicTodo_T = TypeVar("MagicTodo_T", bound="AbstractMagicTodo")
+T = TypeVar("T", bound="AbstractTodo")
 
+# Type of a spell function which transforms a line (i.e. a str).
+LineSpell = Callable[[str], str]
 # Type of the Todo.metadata attribute.
 Metadata = Dict[str, Union[str, List[str]]]
 # A todo item's priority is always a capital letter.
@@ -62,20 +60,23 @@ Priority = Literal[
     "Z",
 ]
 # Type of spell functions used by MagicTodo objects.
-TodoSpell = Callable[["Todo"], Result["Todo", ErisError]]
+TodoSpell = Callable[[T], Result[T, ErisError]]
 
 
 @runtime_checkable
-class AbstractTodo(Comparable, ToDictable, Protocol):
+class AbstractTodo(Comparable, Protocol):
     """Describes how any valid Todo object should look."""
 
     @classmethod
-    def from_line(cls: Type[Todo_T], line: str) -> Result[Todo_T, ErisError]:
+    def from_line(cls: Type[T], line: str) -> Result[T, ErisError]:
         """Constructs a new Todo object from a string."""
 
     def to_line(self) -> str:
         """Converts a Todo object back to a string."""
 
+    def new(self: T, **kwargs: Any) -> T:
+        """Creates a new Todo using the current Todo's attrs as defaults."""
+
     @property
     def contexts(self) -> Tuple[str, ...]:  # noqa: D102
         """A todo's contexts.
@@ -96,7 +97,7 @@ class AbstractTodo(Comparable, ToDictable, Protocol):
         """The date this todo was completed."""
 
     @property
-    def marked_done(self) -> bool:  # noqa: D102
+    def done(self) -> bool:  # noqa: D102
         """Is this todo marked done with an 'x'?"""
 
     @property
@@ -119,20 +120,27 @@ class AbstractTodo(Comparable, ToDictable, Protocol):
 
 
 @runtime_checkable
-class AbstractMagicTodo(AbstractTodo, Protocol):
+class AbstractMagicTodo(AbstractTodo, Protocol, Generic[T]):
     """Describes how subclasses of MagicTodoMixin should look."""
 
-    pre_spells: List[TodoSpell]
-    spells: List[TodoSpell]
-    post_spells: List[TodoSpell]
+    to_line_spells: List[LineSpell]
+    from_line_spells: List[LineSpell]
+    todo_spells: List[TodoSpell]
 
-    def __init__(self, todo: "Todo") -> None:
+    def __init__(self, todo: T) -> None:
         pass
 
     @classmethod
-    def cast_spells(cls, todo: "Todo") -> Result["Todo", ErisError]:
+    def cast_todo_spells(cls, todo: T) -> Result[T, ErisError]:
         """Casts all spells associated with this MagicTodo on `todo`."""
 
+    @classmethod
+    def cast_from_line_spells(cls, line: str) -> str:
+        """Casts all from_line spells on `line`."""
+
+    def cast_to_line_spells(self, line: str) -> str:
+        """Casts all to_line spells on `line`."""
+
     @property
-    def todo(self) -> "Todo":
+    def todo(self) -> T:
         """The raw Todo object used by this MagicTodo."""
